@@ -3,6 +3,7 @@
 import ee
 from .. import indices, bitreader
 from datetime import date
+from .. import tools
 
 TODAY = date.today().isoformat()
 
@@ -135,6 +136,8 @@ class Band(object):
 
 class Collection(object):
     """ Parent class for common operations """
+    SHORTS = {}
+
     def __init__(self, **kwargs):
         self._id = None
         self._bands = None
@@ -143,6 +146,21 @@ class Collection(object):
         self.end_date = kwargs.get('end_date', None)
         self.cloud_cover = kwargs.get('cloud_cover', None)
         self.algorithms = kwargs.get('algorithms', {})
+        self.common_masks = [lambda i: i]
+        self.short_name = self.SHORTS.get(self.id)
+
+    @staticmethod
+    def fromId(id):
+        return None
+
+    @classmethod
+    def fromShortName(cls, short_name):
+        inverse = {v: k for k, v in cls.SHORTS.items()}
+        if short_name not in inverse:
+            raise ValueError("{} not recognized as a valid short name".format(short_name))
+        else:
+            cid = inverse[short_name]
+            return cls.fromId(cid)
 
     @property
     def id(self):
@@ -245,6 +263,14 @@ class Collection(object):
         """ Get a mask image """
         bandnames = self.bandNames(renamed=renamed)
 
+        # SCL Mask
+        if self.id == 'COPERNICUS/S2_SR' and mask_band == 'SCL':
+            if classes == 'all':
+                classes = ['dark','shadow', 'vegetation','bare_soil', 'water',
+                'cloud_low', 'cloud_medium', 'cloud_high', 'cirrus_cloud',
+                'snow']
+            return ee.Image(self.SclMasks(image)).select(classes)
+
         # CHECKS
         if mask_band not in bandnames:
             msg = 'band {} not present in bands {}'
@@ -269,16 +295,20 @@ class Collection(object):
 
     def applyMask(self, image, mask_band, classes='all', renamed=False):
         """ Apply a mask """
-        mask = self.getMask(image, mask_band, classes, renamed)
-        options = mask.bandNames()
+        # SCL Mask
+        if classes == 'all':
+            if self.id == 'COPERNICUS/S2_SR' and mask_band == 'SCL':
+                bands = ['dark','shadow', 'cloud_low', 'cloud_medium',
+                         'cloud_high', 'cirrus_cloud', 'snow']
+            else:
+                bands = None
+        else:
+            bands = classes
 
-        def wrap(band, img):
-            img = ee.Image(img)
-            band = ee.String(band)
-            m = mask.select(band)
-            return img.updateMask(m.Not())
+        if isinstance(mask_band, str):
+            mask_band = self.getMask(image, mask_band, classes, renamed)
 
-        return ee.Image(options.iterate(wrap, image))
+        return tools.image.applyMask(image, mask_band, bands)
 
     def applyPositiveMask(self, image, mask_band, classes='all',
                           renamed=False):
@@ -532,6 +562,25 @@ def fromId(id):
     raise ValueError('{} not recognized as a valid ID'.format(id))
 
 
+def fromShortName(short_name):
+    """ Create a collection from a short name """
+    functions = [
+        landsat.Landsat.fromShortName,
+        sentinel.Sentinel2.fromShortName,
+        modis.MODIS.fromShortName
+    ]
+    for f in functions:
+        try:
+            col = f(short_name)
+        except:
+            continue
+        else:
+            return col
+
+    # tried all collections and did not find it
+    raise ValueError('{} not recognized as a valid short name'.format(short_name))
+
+
 def getCommonBands(*collections, reference='all', match='id'):
     """ Get the common bands of the parsed collections
 
